@@ -1,5 +1,5 @@
 name = "csinscapp"
-version = "0.0.6"
+version = "0.0.7"
 
 # tested on remi version = "2020.3.10"
 import remi.gui as gui
@@ -104,7 +104,7 @@ class Control:
   def x(self, value): 
     self._x = value
     if CSinSCApp.buffered_mode:
-      CSinSCApp.styles[self] = ["left", f"{self._x}px;"]
+      CSinSCApp.styles[self]["left"] = f"{self._x}px;"
     else:
       self.widget.style["left"] = f"{self._x}px;"
 
@@ -115,7 +115,7 @@ class Control:
   def y(self, value): 
     self._y = value
     if CSinSCApp.buffered_mode:
-      CSinSCApp.styles[self] = ["top", f"{self._y}px;"]
+      CSinSCApp.styles[self]["top"] = f"{self._y}px;"
     else:
       self.widget.style["top"] = f"{self._y}px;"      
 
@@ -130,7 +130,7 @@ class Control:
     if not isinstance(width, str):
       width = f"{self._width}px;"
     if CSinSCApp.buffered_mode:
-      CSinSCApp.styles[self] = ["width", width]
+      CSinSCApp.styles[self]["width"] = width
     else:
       self.widget.style["width"] = width
 
@@ -145,7 +145,7 @@ class Control:
     if not isinstance(height, str):
       height = f"{self._height}px;"
     if CSinSCApp.buffered_mode:
-      CSinSCApp.styles[self] = ["height", height]
+      CSinSCApp.styles[self]["height"] = height
     else:
       self.widget.style["height"] = height
 
@@ -156,7 +156,7 @@ class Control:
   def y(self, value): 
     self._y = value
     if CSinSCApp.buffered_mode:
-      CSinSCApp.styles[self] = ["top", f"{self._y}px;"]
+      CSinSCApp.styles[self]["top"] = f"{self._y}px;"
     else:
       self.widget.style["top"] = f"{self._y}px;"         
 
@@ -168,7 +168,7 @@ class Control:
     self._visible = value
 
     if CSinSCApp.buffered_mode:
-      CSinSCApp.styles[self] = ["display", "inline;" if self._visible == True else "none;"]
+      CSinSCApp.styles[self]["display"] = "inline;" if self._visible == True else "none;"
     else:
       self.widget.style["display"] = "inline;" if self._visible == True else "none;"
 
@@ -389,6 +389,7 @@ class CSinSCApp:
 
   def addControl(self, control):
     self.container.append(control.widget)
+    CSinSCApp.styles[control] = {}
     control.widget.onclick.do(self.on_click, control)
     # BUG in REMI - onmouseover removed from version 2020.3
     #control.widget.onmouseover.do(self.on_mouse_over, control)
@@ -419,10 +420,14 @@ class CSinSCApp:
 
     # apply all styles
     for control in CSinSCApp.styles.keys():
-      control.widget.style[CSinSCApp.styles[control][0]] = CSinSCApp.styles[control][1]
+      for style in CSinSCApp.styles[control].keys():        
+        control.widget.style[style] = CSinSCApp.styles[control][style]
 
     CSinSCApp.commands = []
-    CSinSCApp.styles = {}
+
+    #clear styles
+    for control in CSinSCApp.styles.keys():
+      CSinSCApp.styles[control] = {}
 
   def readResource(filename):
 
